VerifyResponse class

Raw response of POST /api/v1/verify/public (pending or confirmed).

Constructors

VerifyResponse({required BondifyStatus status, BondifyUser? user})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status BondifyStatus
final
user BondifyUser?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited